######################################
# Drawing phylogenetic tree (Fig.S5) #
######################################
# Loading packages
  library(ape)


# First, we prepare for data.
  tree <- read.tree("tree.new")
  data <- read.csv("phylo_plant.csv")
  data$mana <- factor(data$mana,levels=c("TRA","ABA","INT"))
  
  ind <- apply(data[,8:ncol(data)],2,sum)
  ind <- ind[ind>0]


# Next, we plot phylogenetic tree.
  tree2 <- tree
  tree2$tip.label <- paste("                                 ",tree$tip.label,"                                 ") 
  plot(tree2, type="fan",tip.col="black",cex=0.2) 

  
# Finaly, we add species abundance.
  theta <- seq(-pi, pi, length=(length(tree$tip.label)+1))
  theta2 <- theta[c(140:length(theta),2:140)]
  legh <- ifelse(apply(data[data$mana=="TRA",][,8:ncol(data)],2,mean)==0,0,apply(data[data$mana=="TRA",][,8:ncol(data)],2,mean))
  legh <- ifelse(legh>0&legh<=1,1,legh)
  legh <- ifelse(legh>1&legh<=5,3,legh)
  legh <- ifelse(legh>5,5,legh)
  points(490*cos(theta2), 490*sin(theta2), asp=1,col="forestgreen",pch=16,cex=1.6*log(legh[paste(tree$tip.label)]+1)/4)
  legh <- ifelse(apply(data[data$mana=="ABA",][,8:ncol(data)],2,mean)==0,0,apply(data[data$mana=="ABA",][,8:ncol(data)],2,mean))
  legh <- ifelse(legh>0&legh<=1,1,legh)
  legh <- ifelse(legh>1&legh<=5,3,legh)
  legh <- ifelse(legh>5,5,legh)
  points(470*cos(theta2), 470*sin(theta2), asp=1,col="blue",pch=16,cex=1.6*log(legh[paste(tree$tip.label)]+1)/4)
  legh <- ifelse(apply(data[data$mana=="INT",][,8:ncol(data)],2,mean)==0,0,apply(data[data$mana=="INT",][,8:ncol(data)],2,mean))
  legh <- ifelse(legh>0&legh<=1,1,legh)
  legh <- ifelse(legh>1&legh<=5,3,legh)
  legh <- ifelse(legh>5,5,legh)
  points(450*cos(theta2), 450*sin(theta2), asp=1,col="red",pch=16,cex=1.6*log(legh[paste(tree$tip.label)]+1)/4)


#######################################################
# Calcurating Evolutionary Distinctiveness (Table S1) #
#######################################################
# Loading packages
  library(ape)
  library(pez)
  
  
# First, we prepare for data.
  tree <- read.tree("tree.new")
  data <- read.csv("phylo_plant.csv")
  data$mana <- factor(data$mana,levels=c("TRA","ABA","INT"))
  
  ind <- apply(data[,8:ncol(data)],2,sum)
  ind <- ind[ind>0]
  
  data.ed <- apply(data[,names(ind)],2,sum)
  data.ed <- rbind(data.ed,ifelse(data.ed>0,1,0))
  rownames(data.ed) <- c("AED","ED")
  tttt <- comparative.comm(tree,data.ed)

  
# Next, we calculate Evolutionary Distinctiveness. 
  res.ed <- .aed(tttt)
  data.abu <- apply(data[data$mana=="TRA",names(ind)],2,sum)
  data.abu <- cbind(data.abu,apply(data[data$mana=="INT",names(ind)],2,sum))
  data.abu <- cbind(data.abu,apply(data[data$mana=="ABA",names(ind)],2,sum))
  colnames(data.abu) <- c("TRA","INT","ABA")
  
  res.ed <- data.frame(res.ed,data.abu[rownames(res.ed),])
  #write.csv(res.ed,file="res.ed.csv")
  
  
######################################################################
# Species loss simulation based on speciesf abundances (Figs. 4 & 5) #
######################################################################
# Loading packages
  library(ape)
  library(pez)
  library(vegan)
  library(picante)
  
  
# We prepare for data.
  tree <- read.tree("tree.new")
  data <- read.csv("phylo_plant.csv")
  data$mana <- factor(data$mana,levels=c("TRA","ABA","INT"))

  ind <- apply(data[,8:ncol(data)],2,sum)
  ind <- ind[ind>0]

  s.mat <- as.matrix(data[,8:ncol(data)])
  s.mat <- s.mat[,apply(s.mat,2,sum)>0]
  rownames(s.mat) <- data$site

  
# First, we create individual pool according to species' abundances.
# (ex. sp1, sp1, sp1, sp2, sp3, sp3, ... , sp10)
  sp <- c()
  for(i in 1:length(ind)){
    sp <- append(sp,rep(names(ind)[i],ind[i]))
  }
  sp <- as.factor(sp)

  
# Next, we run species loss simulation.
# The species loss simulation is consisted 2 steps.
#   Step1: species loss step 
#          We remove individuals randomly from individual pool. 
#   Step2: calculate indecis step
#          We calculate diversity indecies 

# Setting species abundances to calculate

#   Run the following codes if you carry out to draw the Fig. 4.
    sim.indno <- seq(0,length(sp),by=10)
    sim.indno[1] <- 1
  
    
#   Run the following code if you carry out to draw the plot Fig. 5.
    sim.indno <- sort(unique(apply(data[,8:ncol(data)],1,sum)))


# simulation
  simno<-5000 #simulation number
  
  res.sp <- c()
  res.shan <- c()
  res.faith <- c()
  res.haed <- c()
  res.mpd.f <- c()
  res.mpd.t <- c()
  res.mat <- c()
  for(sim in 1:simno){
    # Step1: species loss step 
    # Sampling individual from the pool without replacement
    # (ex. sp3, sp1, sp10, sp2, sp3, sp1, ... , sp1)
      sp.null <- sample(sp)
    
      
    # Step2: calculate indecis step
    # Caluculating six diversity indices by setted species abundance
      mat.sp <- c()
      res.sp1 <- c()
      for(i in sim.indno){
        mat.sp1 <- t(as.matrix(table(sp.null[1:i])))
        mat.sp <- rbind(mat.sp,mat.sp1)
        res.sp1 <- apply(ifelse(mat.sp>0,1,0),1,sum)
      }
      
      rownames(mat.sp) <- sim.indno
      
      res.sp <- rbind(res.sp,res.sp1)
      res.shan <- rbind(res.shan,diversity(mat.sp,index="shannon"))
      res.faith <- rbind(res.faith,pd(mat.sp,tree)$PD)
      tttt <- comparative.comm(tree,mat.sp)
      res.haed1 <- .haed(tttt)
      res.haed <- rbind(res.haed,res.haed1)
      
      res.mpd.f1 <- .mpd(tttt, abundance.weighted = F)
      res.mpd.f <- rbind(res.mpd.f,res.mpd.f1)
      
      res.mpd.t1 <- .mpd(tttt, abundance.weighted = T)
      res.mpd.t <- rbind(res.mpd.t,res.mpd.t1)
      
      
      res.mat[[sim]] <- mat.sp
      print(sim)
    }
    colnames(res.sp) <- sim.indno
    colnames(res.shan) <- sim.indno
    colnames(res.faith) <- sim.indno
    colnames(res.haed) <- sim.indno
    colnames(res.mpd.t) <- sim.indno
    colnames(res.mpd.f) <- sim.indno


###############
# Fig. 4 plot # 
###############
# Defining function.    
  quantile95 <- function(x){
    quantile(x,probs=c(0.025,0.975))
  }
    
    
  par(mfrow=c(3,2))

# Species richness
  res.sp <- res.sp[,paste(sim.indno)]
  
  res.sp95 <- apply(res.sp,2,quantile95)
  
  plot(1,1,type="n",xlim=c(1,length(sp)),ylim=c(0,max(res.sp)),ylab="No. of species",xlab="No. of individual")
  polygon(c(colnames(res.sp95),rev(colnames(res.sp95))),c(res.sp95[1,],rev(res.sp95[2,])),col="gray",border=F)
  
  s.mat <- as.matrix(data[,8:ncol(data)])
  rownames(s.mat) <- rownames(data)
  s.mat10 <- ifelse(s.mat>0,1,0)
  sp.site <- apply(s.mat10,1,sum)
  
  indno <- apply(data[,8:ncol(data)],1,sum)
  
  res.mean <- apply(res.sp,2,mean)
  points(res.mean~colnames(res.sp95),type="l")
  
  points(sp.site~indno,col=c("forestgreen","blue","red")[data[,"mana"]],pch=16,cex=0.5)


# Shannon diversity
  res.shan <- res.shan[,paste(sim.indno)]
  res.shan95 <- apply(res.shan,2,quantile95)
  
  plot(1,1,type="n",xlim=c(1,length(sp)),ylim=c(0,max(res.shan)),ylab="shannon",xlab="No. of individual")
  polygon(c(colnames(res.shan95),rev(colnames(res.shan95))),c(res.shan95[1,],rev(res.shan95[2,])),col="gray",border=F)
  
  s.mat <- as.matrix(data[,8:ncol(data)])
  rownames(s.mat) <- rownames(data)
  
  real.shan <- diversity(s.mat,index="shannon")
  indno <- apply(data[,8:ncol(data)],1,sum)
  
  res.mean <- apply(res.shan,2,mean)
  points(res.mean~colnames(res.shan95),type="l")
  
  points(real.shan~indno,col=c("forestgreen","blue","red")[data[,"mana"]],pch=16,cex=0.5)
  

# Faith's PD
  res.faith <- res.faith[,paste(sim.indno)]
  res.faith95 <- apply(res.faith,2,quantile95)
  
  plot(1,1,type="n",xlim=c(1,length(sp)),ylim=c(0,max(res.faith)),ylab="Faith",xlab="No. of individual")
  polygon(c(colnames(res.faith95),rev(colnames(res.faith95))),c(res.faith95[1,],rev(res.faith95[2,])),col="gray",border=F)
  
  s.mat <- as.matrix(data[,8:ncol(data)])
  rownames(s.mat) <- rownames(data)
  real.faith <- pd(s.mat,tree)$PD
  indno <- apply(data[,8:ncol(data)],1,sum)
  
  res.mean <- apply(res.faith,2,mean)
  
  points(res.mean~colnames(res.faith95),type="l")
  points(real.faith~indno,col=c("forestgreen","blue","red")[data[,"mana"]],pch=16,cex=0.5)


# Haed
  res.haed <- res.haed[,paste(sim.indno)]
  res.haed95 <- apply(res.haed,2,quantile95)
  
  plot(1,1,type="n",xlim=c(1,length(sp)),ylim=c(0,max(res.haed)),ylab="Haed",xlab="No. of individual")
  polygon(c(colnames(res.haed95),rev(colnames(res.haed95))),c(res.haed95[1,],rev(res.haed95[2,])),col="gray",border=F)
  
  s.mat <- as.matrix(data[,8:ncol(data)])
  rownames(s.mat) <- rownames(data)
  tttt <- comparative.comm(tree,s.mat[,apply(s.mat,2,sum)>0])
  real <- .haed(tttt)
  indno <- apply(data[,8:ncol(data)],1,sum)
  
  res.mean <- apply(res.haed,2,mean)
  points(res.mean~colnames(res.haed95),type="l")
  
  points(real~indno,col=c("forestgreen","blue","red")[data[,"mana"]],pch=16,cex=0.5)

  
# MPD(incidence)
  res.mpd.f<-res.mpd.f[,paste(sim.indno)]
  res.mpd.f95 <- apply(res.mpd.f[,-1],2,quantile95)
  
  plot(1,1,type="n",xlim=c(1,length(sp)),ylim=c(min(res.mpd.f95,na.rm=T),max(res.mpd.f95,na.rm=T)),ylab="MPD ABU=F",xlab="No. of individual")
  polygon(c(colnames(res.mpd.f95),rev(colnames(res.mpd.f95))),c(res.mpd.f95[1,],rev(res.mpd.f95[2,])),col="gray",border=F)
  
  s.mat <- as.matrix(data[,8:ncol(data)])
  rownames(s.mat) <- rownames(data)
  tttt <- comparative.comm(tree,s.mat[,apply(s.mat,2,sum)>0])
  real <- .mpd(tttt,abundance.weighted = F)
  indno <- apply(data[,8:ncol(data)],1,sum)
  
  res.mean <- apply(res.mpd.f[,-1],2,mean)
  points(res.mean~colnames(res.mpd.f95),type="l")
  points(real~indno,col=c("forestgreen","blue","red")[data[,"mana"]],pch=16,cex=0.5
  )


# MPD(abundance)
  res.mpd.t<-res.mpd.t[,paste(sim.indno)]
  res.mpd.t95 <- apply(res.mpd.t[,-1],2,quantile95)
  
  plot(1,1,type="n",xlim=c(1,length(sp)),ylim=c(124,max(res.mpd.t95,na.rm=T)),ylab="MPD ABU=T",xlab="No. of individual")
  polygon(c(colnames(res.mpd.t95),rev(colnames(res.mpd.t95))),c(res.mpd.t95[1,],rev(res.mpd.t95[2,])),col="gray",border=F)
  
  
  s.mat <- as.matrix(data[,8:ncol(data)])
  rownames(s.mat) <- rownames(data)
  tttt <- comparative.comm(tree,s.mat[,apply(s.mat,2,sum)>0])
  real <- .mpd(tttt,abundance.weighted = T)
  indno <- apply(data[,8:ncol(data)],1,sum)
  
  res.mean <- apply(res.mpd.t[,-1],2,mean)
  points(res.mean~colnames(res.mpd.t95),type="l")
  points(real~indno,col=c("forestgreen","blue","red")[data[row.names(data),"mana"]],pch=16,cex=0.5
  )
  
  
##################
# Fig. 5 boxplot # 
##################
par(mfrow=c(3,2))
# Species richness
  indno <- apply(data[,8:ncol(data)],1,sum)
  sort.res <- res.sp[,paste(indno)]
  
  s.mat <- as.matrix(data[,8:ncol(data)])
  rownames(s.mat) <- rownames(data)
  s.mat10 <- ifelse(s.mat>0,1,0)
  sp.site <- apply(s.mat10,1,sum)
  
  SES <- (sp.site-apply(sort.res,2,mean))/apply(sort.res,2,sd)
  
  boxplot(SES~data$mana,col=c("forestgreen","blue","red"),main="No. of species",ylim=c(min(SES),0))
  
  res.SES <- data.frame(data$mana,sp.site,SES)
  names(res.SES) <- c("mana","spno.real","spno.SES")
  

# Shannon diversity
  indno <- apply(data[,8:ncol(data)],1,sum)
  sort.res <- res.shan[,paste(indno)]
  
  s.mat <- as.matrix(data[,8:ncol(data)])
  rownames(s.mat) <- rownames(data)
  real.shan <- diversity(s.mat,index="shannon")
  
  SES <- (real.shan-apply(sort.res,2,mean))/apply(sort.res,2,sd)
  
  boxplot(SES~data$mana,col=c("forestgreen","blue","red"),main="Shannon",ylim=c(min(SES),0))
  
  res.SES$shan.real <- real.shan
  res.SES$shan.SES <- SES

  
# Faith's PD
  indno <- apply(data[,8:ncol(data)],1,sum)
  sort.res <- res.faith[,paste(indno)]
  
  s.mat <- as.matrix(data[,8:ncol(data)])
  rownames(s.mat) <- rownames(data)
  real.faith <- pd(s.mat,tree)$PD
  
  SES <- (real.faith-apply(sort.res,2,mean))/apply(sort.res,2,sd)
  
  boxplot(SES~data$mana,col=c("forestgreen","blue","red"),main="Faith",ylim=c(min(SES),0))
  
  res.SES$faith.real <- real.faith
  res.SES$faith.SES <- SES
  

# Haed
  indno <- apply(data[,8:ncol(data)],1,sum)
  sort.res <- res.haed[,paste(indno)]
  
  s.mat <- as.matrix(data[,8:ncol(data)])
  rownames(s.mat) <- rownames(data)
  tttt <- comparative.comm(tree,s.mat[,apply(s.mat,2,sum)>0])
  real <- .haed(tttt)
  
  SES <- (real-apply(sort.res,2,mean))/apply(sort.res,2,sd)
  
  boxplot(SES~data$mana,col=c("forestgreen","blue","red"),main="Haed")
  
  res.SES$haed.real <- real
  res.SES$haed.SES <- SES

  
# MPD(incidence)
  indno <- apply(data[,8:ncol(data)],1,sum)
  sort.res <- res.mpd.f[,paste(indno)]
  
  s.mat <- as.matrix(data[,8:ncol(data)])
  rownames(s.mat) <- rownames(data)
  s.mat2 <- s.mat[,apply(s.mat,2,sum)>0]
  tttt <- comparative.comm(tree,s.mat2)
  real <- .mpd(tttt,abundance.weighted = F)
  
  SES <- (real-apply(sort.res,2,mean))/apply(sort.res,2,sd)
  
  boxplot(SES~data$mana,col=c("forestgreen","blue","red"),main="MPD ABU=F")
  
  res.SES$mpd.f.real <- real
  res.SES$mpd.f.SES <- SES

# MPD(abundance)
  indno <- apply(data[,8:ncol(data)],1,sum)
  sort.res <- res.mpd.t[,paste(indno)]
  
  s.mat <- as.matrix(data[,8:ncol(data)])
  rownames(s.mat) <- rownames(data)
  s.mat2 <- s.mat[,apply(s.mat,2,sum)>0]
  tttt <- comparative.comm(tree,s.mat2)
  real <- .mpd(tttt,abundance.weighted = T)
  
  SES <- (real-apply(sort.res,2,mean))/apply(sort.res,2,sd)
  
  boxplot(SES~data$mana,col=c("forestgreen","blue","red"),main="MPD ABU=T")
  
  res.SES$mpd.t.real <- real
  res.SES$mpd.t.SES <- SES
  
  #write.csv(res.SES,"res.SES.csv")


#########################################################
# Analysing phylogenetic community assemblage (Fig. 6) #
#########################################################
# Loading packages
  library(ape)
  library(geiger)

# We prepare for data.
  tree <- read.tree("tree.new")
  data <- read.csv("phylo_plant.csv")
  data$mana <- factor(data$mana,levels=c("TRA","ABA","INT"))

  ind <- apply(data[,8:ncol(data)],2,sum)
  ind <- ind[ind>0]
  
  random.tree <- tree
  s.mat <- as.matrix(data[,8:ncol(data)])
  rownames(s.mat) <- rownames(data)
  s.mat <- s.mat[,names(ind)]


# Next, we run phylogenetic tree randomized simulation 

  simno <- 5000 #simulation number
  
  sp.mpd.t <- c()
  sp.mpd.f <- c()
  for(i in 1:simno){
    # We randomize tip label.
    random.tree$tip.label <- sample(random.tree$tip.label)
    # We calculate mpd indeces.
    tttt <- comparative.comm(random.tree,s.mat)
    sp.mpd.f1 <- .mpd(tttt, abundance.weighted = F)
    sp.mpd.f <- rbind(sp.mpd.f,sp.mpd.f1)
    sp.mpd.t1 <- .mpd(tttt, abundance.weighted = T)
    sp.mpd.t <- rbind(sp.mpd.t,sp.mpd.t1)
    print(i)
  }


##################
# Fig. 6 boxplot #
##################
par(mfrow=c(1,2))

res.SES <- data.frame(data$mana)

s.mat <- as.matrix(data[,8:ncol(data)])
rownames(s.mat) <- rownames(data)
s.mat2 <- s.mat[,apply(s.mat,2,sum)>0]
tttt <- comparative.comm(tree,s.mat2)


# MPD(incidence)
  real.mpd.f <- .mpd(tttt,abundance.weighted = F)
  SES <- (real.mpd.f-apply(sp.mpd.f,2,mean))/apply(sp.mpd.f,2,sd)
  boxplot(SES~data$mana,col=c("forestgreen","blue","red"),main="MPD ABU=F")
  res.SES$mpd.f.real <- real.mpd.f
  res.SES$mpd.f.SES <- SES

  
# MPD(abundance)
  real.mpd.t <- .mpd(tttt,abundance.weighted = T)
  SES <- (real.mpd.t-apply(sp.mpd.t,2,mean))/apply(sp.mpd.t,2,sd)
  boxplot(SES~data$mana,col=c("forestgreen","blue","red"),main="MPD ABU=T")
  
  res.SES$mpd.t.real <- real.mpd.t
  res.SES$mpd.t.SES <- SES
  
  #write.csv(res.SES,"res.Tree.csv")



